@@ -5,6 +5,7 @@ use parent 'Exporter';
 our @EXPORT = qw(all_plugins_in_prereqs);
 
 use Test::More;
+use Test::Deep;
 use List::MoreUtils 'uniq';
 use Path::Tiny;
 use JSON::MaybeXS;
@@ -30,6 +31,8 @@ sub all_plugins_in_prereqs
     my $pluginbundle_meta = decode_json(path('META.json')->slurp_raw);
     my $dist_meta = $tzil->distmeta;
 
+    my $bundle_plugin_prereqs = $tzil->plugin_named('@Author::ETHER/bundle_plugins')->_prereq;
+
     subtest 'all plugins in use are specified as *required* runtime prerequisites by the plugin bundle, or develop prerequisites by the distribution' => sub {
         foreach my $plugin (uniq map { $_->meta->name } @{$tzil->plugins})
         {
@@ -37,6 +40,11 @@ sub all_plugins_in_prereqs
                 if exists $exempt{$plugin};
             next if $plugin eq 'Dist::Zilla::Plugin::FinderCode';  # added automatically by dist builder
 
+            # the plugin should have been added to develop prereqs - look for
+            # an explicit :version requirement there
+            my $required_version = $bundle_plugin_prereqs->{$plugin->meta->name} // 0;
+            $required_version = any($required_version, re(qr/[^\d.]/));
+
             if (exists $additional{$plugin})
             {
                 ok(
@@ -44,15 +52,18 @@ sub all_plugins_in_prereqs
                     $plugin . ' is a develop prereq of the distribution',
                 ) or diag 'got dist metadata: ', explain $dist_meta;
 
-                ok(
-                    exists $pluginbundle_meta->{prereqs}{runtime}{recommends}{$plugin},
+                cmp_deeply(
+                    $pluginbundle_meta->{prereqs}{runtime}{recommends},
+                    superhashof({ $plugin => $required_version }),
                     $plugin . ' is a runtime recommendation of the plugin bundle',
                 ) or diag 'got plugin bundle metadata: ', explain $pluginbundle_meta;
             }
             else
             {
-                ok(
-                    exists $pluginbundle_meta->{prereqs}{runtime}{requires}{$plugin},
+                cmp_deeply(
+                    $pluginbundle_meta->{prereqs}{runtime}{requires},
+                    superhashof({ $plugin => $required_version }),
+
                     $plugin . ' is a runtime prereq of the plugin bundle',
                 ) or diag 'got plugin bundle metadata: ', explain $pluginbundle_meta;
             }
